#SmartMeterTexas API

This is an API for [SmartMeterTexas.com](https://www.smartmetertexas.com) written in Python. It is still in early development and any assistance is appreciated.

Be aware, this is my first attempt at a project with the goal of being added to PyPI and be a rather advanced tool for other developers. This project came about because I found no python tool to work with SmartMeterTexas' API. So I decided to make such a tool for other programs.

Any advice or tools to make the code more readable and robust would be very welcome.
